# JellyServe

JellyServe is a simple and flexible web framework written in Python with native support for .svelte files.

What works?
* Routing (dynamic routes, matchers, etc.)
* Svelte file compilation and population
* Simple database integration (alpha)
* Messages (simpler websockets)

What does not work/is planned?
* Testing utility
* Wiki through GitHub Wikis

The code is spaghetti. But it works. Maybe i will rewrite it in the future.